( cd usr/lib64 ; rm -rf libart_lgpl_2.so.2 )
( cd usr/lib64 ; ln -sf libart_lgpl_2.so.2.3.17 libart_lgpl_2.so.2 )
( cd usr/lib64 ; rm -rf libart_lgpl_2.so )
( cd usr/lib64 ; ln -sf libart_lgpl_2.so.2.3.17 libart_lgpl_2.so )
